@@ -1,7 +1,6 @@
 import sys
 import time
 import datetime
-from io import open
 from os import path
 from textwrap import wrap
 
@@ -13,12 +12,15 @@ from sphinx.util.osutil import make_filename
 
 from .version import version as __version__
 
-w = lambda t, ls=80: "\n".join(wrap(t, ls))
+
+def w(t, ls=80):
+    return "\n".join(wrap(t, ls))
+
 
 __all__ = ["generate", "ask_user", "ablog_start"]
 
-ABLOG_CONF = "#!/usr/bin/env python3\n"
-ABLOG_CONF += """# -*- coding: utf-8 -*-
+ABLOG_CONF = "#!/usr/bin/env python\n"
+ABLOG_CONF += """
 
 # %(project)s build configuration file, created by
 # `ablog start` on %(now)s.
@@ -35,7 +37,7 @@ import alabaster
 # -- General ABlog Options ----------------------------------------------------
 
 # A path relative to the configuration directory for blog archive pages.
-#blog_path = 'blog'
+# blog_path = 'blog'
 
 # The "title" for the blog, used in active pages.  Default is ``'Blog'``.
 blog_title = u'%(project_str)s Blog'
@@ -46,7 +48,7 @@ blog_baseurl = u'%(blog_baseurl)s'
 
 # Choose to archive only post titles. Archiving only titles can speed
 # up project building.
-#blog_archive_titles = False
+# blog_archive_titles = False
 
 # -- Blog Authors, Languages, and Locations -----------------------------------
 
@@ -62,50 +64,50 @@ blog_authors = {
 # links of these languages. Similar to :confval:`blog_authors`, dictionary
 # keys should be used in ``post`` directive to refer to the locations.
 # Default is ``{}``.
-#blog_languages = {
+# blog_languages = {
 #    'en': ('English', None),
-#}
+# }
 
 
 # A dictionary of location names mapping to full display names and
 # links of these locations. Similar to :confval:`blog_authors`, dictionary
 # keys should be used in ``post`` directive to refer to the locations.
 # Default is ``{}``.
-#blog_locations = {
+# blog_locations = {
 #    'Earth': ('The Blue Planet', 'https://en.wikipedia.org/wiki/Earth),
-#}
+# }
 
 # -- Blog Post Related --------------------------------------------------------
 
 # Format date for a post.
-#post_date_format = '%%b %%d, %%Y'
+# post_date_format = '%%b %%d, %%Y'
 
 # Number of paragraphs (default is ``1``) that will be displayed as an excerpt
 # from the post. Setting this ``0`` will result in displaying no post excerpt
 # in archive pages.  This option can be set on a per post basis using
-#post_auto_excerpt = 1
+# post_auto_excerpt = 1
 
 # Index of the image that will be displayed in the excerpt of the post.
 # Default is ``0``, meaning no image.  Setting this to ``1`` will include
 # the first image, when available, to the excerpt.  This option can be set
 # on a per post basis using :rst:dir:`post` directive option ``image``.
-#post_auto_image = 0
+# post_auto_image = 0
 
 # Number of seconds (default is ``5``) that a redirect page waits before
 # refreshing the page to redirect to the post.
-#post_redirect_refresh = 5
+# post_redirect_refresh = 5
 
 # When ``True``, post title and excerpt is always taken from the section that
 # contains the :rst:dir:`post` directive, instead of the document. This is the
 # behavior when :rst:dir:`post` is used multiple times in a document. Default
 # is ``False``.
-#post_always_section = False
+# post_always_section = False
 
 # When ``False``, the :rst:dir:`orphan` directive is not automatically set
 # for each post. Without this directive, Sphinx will warn about posts that
 # are not explicitly referenced via another document. :rst:dir:`orphan` can
 # be set on a per-post basis as well if this is false. Default is ``True``.
-#post_auto_orphan = True
+# post_auto_orphan = True
 
 # -- ABlog Sidebars -------------------------------------------------------
 
@@ -129,20 +131,20 @@ html_sidebars = {
 # Turn feeds by setting :confval:`blog_baseurl` configuration variable.
 # Choose to create feeds per author, location, tag, category, and year,
 # default is ``False``.
-#blog_feed_archives = False
+# blog_feed_archives = False
 
 # Choose to display full text in blog feeds, default is ``False``.
-#blog_feed_fulltext = False
+# blog_feed_fulltext = False
 
 # Blog feed subtitle, default is ``None``.
-#blog_feed_subtitle = None
+# blog_feed_subtitle = None
 
 # Choose to feed only post titles, default is ``False``.
-#blog_feed_titles = False
+# blog_feed_titles = False
 
 # Specify number of recent posts to include in feeds, default is ``None``
 # for all posts.
-#blog_feed_length = None
+# blog_feed_length = None
 
 # -- Font-Awesome Options -----------------------------------------------------
 
@@ -151,29 +153,29 @@ html_sidebars = {
 
 # Link to `Font Awesome`_ at `Bootstrap CDN`_ and use icons in sidebars
 # and post footers.  Default: ``None``
-#fontawesome_link_cdn = None
+# fontawesome_link_cdn = None
 
 # Sphinx_ theme already links to `Font Awesome`_.  Default: ``False``
-#fontawesome_included = False
+# fontawesome_included = False
 
 # Alternatively, you can provide the path to `Font Awesome`_ :file:`.css`
 # with the configuration option: fontawesome_css_file
 # Path to `Font Awesome`_ :file:`.css` (default is ``None``) that will
 # be linked to in HTML output by ABlog.
-#fontawesome_css_file = None
+# fontawesome_css_file = None
 
 # -- Disqus Integration -------------------------------------------------------
 
 # You can enable Disqus_ by setting ``disqus_shortname`` variable.
 # Disqus_ short name for the blog.
-#disqus_shortname = None
+# disqus_shortname = None
 
 # Choose to disqus pages that are not posts, default is ``False``.
-#disqus_pages = False
+# disqus_pages = False
 
 # Choose to disqus posts that are drafts (without a published date),
 # default is ``False``.
-#disqus_drafts = False
+# disqus_drafts = False
 
 # -- Sphinx Options -----------------------------------------------------------
 
@@ -198,7 +200,7 @@ templates_path = ['%(dot)stemplates', ablog.get_html_templates_path()]
 source_suffix = '%(suffix)s'
 
 # The encoding of source files.
-#source_encoding = 'utf-8-sig'
+# source_encoding = 'utf-8-sig'
 
 # The master toctree document.
 master_doc = '%(master_str)s'
@@ -226,9 +228,9 @@ language = %(language)r
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
-#today = ''
+# today = ''
 # Else, today_fmt is used as the format for a strftime call.
-#today_fmt = '%%B %%d, %%Y'
+# today_fmt = '%%B %%d, %%Y'
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
@@ -236,27 +238,27 @@ exclude_patterns = [%(exclude_patterns)s]
 
 # The reST default role (used for this markup: `text`) to use for all
 # documents.
-#default_role = None
+# default_role = None
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
-#add_function_parentheses = True
+# add_function_parentheses = True
 
 # If true, the current module name will be prepended to all description
 # unit titles (such as .. function::).
-#add_module_names = True
+# add_module_names = True
 
 # If true, sectionauthor and moduleauthor directives will be shown in the
 # output. They are ignored by default.
-#show_authors = False
+# show_authors = False
 
 # The name of the Pygments (syntax highlighting) style to use.
 pygments_style = 'sphinx'
 
 # A list of ignored prefixes for module index sorting.
-#modindex_common_prefix = []
+# modindex_common_prefix = []
 
 # If true, keep warnings as "system message" paragraphs in the built documents.
-#keep_warnings = False
+# keep_warnings = False
 
 # If true, `todo` and `todoList` produce output, else they produce nothing.
 todo_include_todos = %(ext_todo)s
@@ -280,19 +282,19 @@ html_theme_path = [alabaster.get_path()]
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
-#html_title = None
+# html_title = None
 
 # A shorter title for the navigation bar.  Default is the same as html_title.
-#html_short_title = None
+# html_short_title = None
 
 # The name of an image file (relative to this directory) to place at the top
 # of the sidebar.
-#html_logo = None
+# html_logo = None
 
 # The name of an image file (within the static path) to use as favicon of the
 # docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
 # pixels large.
-#html_favicon = None
+# html_favicon = None
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -302,59 +304,59 @@ html_static_path = ['%(dot)sstatic']
 # Add any extra paths that contain custom files (such as robots.txt or
 # .htaccess) here, relative to this directory. These files are copied
 # directly to the root of the documentation.
-#html_extra_path = []
+# html_extra_path = []
 
 # If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
 # using the given strftime format.
-#html_last_updated_fmt = '%%b %%d, %%Y'
+# html_last_updated_fmt = '%%b %%d, %%Y'
 
 # If true, SmartyPants will be used to convert quotes and dashes to
 # typographically correct entities.
-#html_use_smartypants = True
+# html_use_smartypants = True
 
 # Additional templates that should be rendered to pages, maps page names to
 # template names.
-#html_additional_pages = {}
+# html_additional_pages = {}
 
 # If false, no module index is generated.
-#html_domain_indices = True
+# html_domain_indices = True
 
 # If false, no index is generated.
-#html_use_index = True
+# html_use_index = True
 
 # If true, the index is split into individual pages for each letter.
-#html_split_index = False
+# html_split_index = False
 
 # If true, links to the reST sources are added to the pages.
-#html_show_sourcelink = True
+# html_show_sourcelink = True
 
 # If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
-#html_show_sphinx = True
+# html_show_sphinx = True
 
 # If true, "(C) Copyright ..." is shown in the HTML footer. Default is True.
-#html_show_copyright = True
+# html_show_copyright = True
 
 # If true, an OpenSearch description file will be output, and all pages will
 # contain a <link> tag referring to it.  The value of this option must be the
 # base URL from which the finished HTML is served.
-#html_use_opensearch = ''
+# html_use_opensearch = ''
 
 # This is the file name suffix for HTML files (e.g. ".xhtml").
-#html_file_suffix = None
+# html_file_suffix = None
 
 # Language to be used for generating the HTML full-text search index.
 # Sphinx supports the following languages:
 #   'da', 'de', 'en', 'es', 'fi', 'fr', 'hu', 'it', 'ja'
 #   'nl', 'no', 'pt', 'ro', 'ru', 'sv', 'tr'
-#html_search_language = 'en'
+# html_search_language = 'en'
 
 # A dictionary with options for the search language support, empty by default.
 # Now only 'ja' uses this config value
-#html_search_options = {'type': 'default'}
+# html_search_options = {'type': 'default'}
 
 # The name of a javascript file (relative to the configuration directory) that
 # implements a search results scorer. If empty, the default will be used.
-#html_search_scorer = 'scorer.js'
+# html_search_scorer = 'scorer.js'
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%(project_fn)sdoc'
@@ -456,9 +458,11 @@ def generate(d, overwrite=True, silent=False):
     d["project_underline"] = column_width(d["project"]) * "="
 
     d["copyright"] = time.strftime("%Y") + ", " + d["author"]
-    d["author_texescaped"] = str(d["author"]).translate(texescape.tex_escape_map)
+    d["author_texescaped"] = texescape.escape(str(d["author"]).translate(str(d["author"])))
     d["project_doc"] = d["project"] + " Documentation"
-    d["project_doc_texescaped"] = str(d["project"] + " Documentation").translate(texescape.tex_escape_map)
+    d["project_doc_texescaped"] = texescape.escape(
+        str(d["project"] + " Documentation").translate(str(d["project"] + " Documentation"))
+    )
 
     # escape backslashes and single quotes in strings that are put into
     # a Python string literal
